# pydel

Python module for parsing [Synthstrom Audible Deluge](https://synthstrom.com/product/deluge/) song files.

## Usage

1. Install [pip](https://pip.pypa.io/en/stable/installing/).

2. Install pydel:
```
pip install pydel
```
